@@ -1,4 +1,4 @@
-#' Skip a test
+#' Skip a test for various reasons
 #'
 #' @description
 #' `skip_if()` and `skip_if_not()` allow you to skip tests, immediately
@@ -19,7 +19,7 @@
 #'
 #' * `skip_if_offline()` skips if an internet connection is not available
 #'   (using [curl::nslookup()]) or if the test is run on CRAN. Requires
-#'   the curl packages to be installed.
+#'   \{curl\} to be installed and included in the dependencies of your package.
 #'
 #' * `skip_if_translated("msg")` skips tests if the "msg" is translated.
 #'
@@ -27,7 +27,8 @@
 #'    env var).
 #'
 #' * `skip_on_cran()` skips on CRAN (using the `NOT_CRAN` env var set by
-#'    devtools and friends).
+#'    devtools and friends). `local_on_cran()` gives you the ability to
+#'    easily simulate what will happen on CRAN.
 #'
 #' * `skip_on_covr()` skips when covr is running (using the `R_COVR` env var).
 #'
@@ -100,16 +101,28 @@ skip_if <- function(condition, message = NULL) {
 #' @param minimum_version Minimum required version for the package
 #' @rdname skip
 skip_if_not_installed <- function(pkg, minimum_version = NULL) {
+  # most common case: it's not installed
+  tryCatch(
+    find.package(pkg),
+    error = function(e) skip(paste0("{", pkg, "} is not installed"))
+  )
+  # rarer: it's installed, but fails to load
   if (!requireNamespace(pkg, quietly = TRUE)) {
-    skip(paste0(pkg, " cannot be loaded"))
+    skip(paste0("{", pkg, "} cannot be loaded"))
   }
 
   if (!is.null(minimum_version)) {
     installed_version <- package_version(pkg)
     if (installed_version < minimum_version) {
       skip(paste0(
-        "Installed ", pkg, " is version ", installed_version, "; ",
-        "but ", minimum_version, " is required"
+        "Installed ",
+        pkg,
+        " is version ",
+        installed_version,
+        "; ",
+        "but ",
+        minimum_version,
+        " is required"
       ))
     }
   }
@@ -121,8 +134,38 @@ package_version <- function(x) {
 }
 
 #' @export
+#' @param spec A version specification like '>= 4.1.0' denoting that this test
+#'   should only be run on R versions 4.1.0 and later.
 #' @rdname skip
-skip_if_offline <- function(host = "r-project.org") {
+skip_unless_r <- function(spec) {
+  check_string(spec)
+
+  parts <- unlist(strsplit(spec, " ", fixed = TRUE))
+  if (length(parts) != 2L) {
+    cli::cli_abort(
+      "{.arg spec} must be an valid version specification, like {.str >= 4.0.0}, not {.str {spec}}."
+    )
+  }
+  comparator <- match.fun(parts[1L])
+  required_version <- numeric_version(parts[2L])
+
+  current_version <- getRversion()
+  skip_if_not(
+    comparator(current_version, required_version),
+    sprintf(
+      "Current R version (%s) does not satisfy requirement (%s %s)",
+      current_version,
+      parts[1L],
+      required_version
+    )
+  )
+}
+# for mocking
+getRversion <- NULL
+
+#' @export
+#' @rdname skip
+skip_if_offline <- function(host = "captive.apple.com") {
   skip_on_cran()
   check_installed("curl")
 
@@ -138,9 +181,27 @@ skip_on_cran <- function() {
   skip_if(on_cran(), "On CRAN")
 }
 
+#' @export
+#' @rdname skip
+#' @param on_cran Pretend we're on CRAN (`TRUE`) or not (`FALSE`).
+#' @param frame Calling frame to tie change to; expect use only.
+local_on_cran <- function(on_cran = TRUE, frame = caller_env()) {
+  check_bool(on_cran)
+  withr::local_envvar(NOT_CRAN = tolower(!on_cran), .local_envir = frame)
+}
+
+# Assert that we're not on CRAN, but don't override the user's setting
+local_assume_not_on_cran <- function(frame = caller_env()) {
+  if (Sys.getenv("NOT_CRAN") != "") {
+    return()
+  }
+  withr::local_envvar("NOT_CRAN" = "true", .local_envir = frame)
+}
+
 #' @export
 #' @param os Character vector of one or more operating systems to skip on.
-#'   Supported values are `"windows"`, `"mac"`, `"linux"`, and `"solaris"`.
+#'   Supported values are `"windows"`, `"mac"`, `"linux"`, `"solaris"`,
+#'   and `"emscripten"`.
 #' @param arch Character vector of one or more architectures to skip on.
 #'   Common values include `"i386"` (32 bit), `"x86_64"` (64 bit), and
 #'   `"aarch64"` (M1 mac). Supplying `arch` makes the test stricter; i.e. both
@@ -149,20 +210,22 @@ skip_on_cran <- function() {
 skip_on_os <- function(os, arch = NULL) {
   os <- match.arg(
     os,
-    choices = c("windows", "mac", "linux", "solaris"),
+    choices = c("windows", "mac", "linux", "solaris", "emscripten"),
     several.ok = TRUE
   )
 
-  msg <- switch(system_os(),
+  msg <- switch(
+    system_os(),
     windows = if ("windows" %in% os) "On Windows",
-    darwin =  if ("mac" %in% os) "On Mac",
-    linux =   if ("linux" %in% os) "On Linux",
-    sunos =   if ("solaris" %in% os) "On Solaris"
+    darwin = if ("mac" %in% os) "On Mac",
+    linux = if ("linux" %in% os) "On Linux",
+    sunos = if ("solaris" %in% os) "On Solaris",
+    emscripten = if ("emscripten" %in% os) "On Emscripten"
   )
 
   if (!is.null(arch) && !is.null(msg)) {
     if (!is.character(arch)) {
-      abort("`arch` must be a character vector")
+      cli::cli_abort("{.arg arch} must be a character vector.")
     }
 
     if (system_arch() %in% arch) {
@@ -240,7 +303,7 @@ skip_on_appveyor <- function() {
 # helpers -----------------------------------------------------------------
 
 on_ci <- function() {
- env_var_is_true("CI")
+  env_var_is_true("CI")
 }
 in_covr <- function() {
   env_var_is_true("R_COVR")
@@ -249,9 +312,18 @@ on_bioc <- function() {
   env_var_is_true("IS_BIOC_BUILD_MACHINE")
 }
 on_cran <- function() {
-  !interactive() && !env_var_is_true("NOT_CRAN")
+  env <- Sys.getenv("NOT_CRAN")
+  if (identical(env, "")) {
+    !interactive()
+  } else {
+    !isTRUE(as.logical(env))
+  }
 }
 
 env_var_is_true <- function(x) {
   isTRUE(as.logical(Sys.getenv(x, "false")))
 }
+
+env_var_is_false <- function(x) {
+  isFALSE(as.logical(Sys.getenv(x, "true")))
+}
