@@ -4,10 +4,14 @@ test_that("basic properties upheld", {
   expect_success(expect_vector(1:10, size = 10))
 
   x <- 1:10
-  expect_snapshot_failure(expect_vector(x, size = 5))
+  expect_snapshot(error = TRUE, {
+    expect_vector(x, size = 5)
+  })
 
   y <- NULL
-  expect_snapshot_failure(expect_vector(y))
+  expect_snapshot(error = TRUE, {
+    expect_vector(y)
+  })
 })
 
 test_that("expect_vector validates its inputs", {
